==> squiggly-clojure-0.1.9-20170221.215855-1.jar: squiggly_clojure/core.clj <==
(ns squiggly-clojure.core
  (:require eastwood.lint
            kibit.check
            clojure.data.json
            clojure.core.typed
            environ.core
            ))

(defn env [ns]
  (or (:squiggly (meta (the-ns ns)))
      (:squiggly environ.core/env)))

(defn do-lint? [checker ns]
  (and (find-ns ns)
       (if-let [checkers (:checkers (env ns))]
         (some #{checker} checkers) true)))

(defn eastwood-exclude-linters [ns]
  (if-let [excl (:eastwood-exclude-linters (env ns))]
    excl []))

(defn eastwood-options [ns]
  (merge {:source-paths ["src"]
          :namespaces [ns]
          :continue-on-exception true
          :exclude-linters (eastwood-exclude-linters ns)}
         (:eastwood-options (env ns))))

(defn permissive-reader [tag value] value)

(defmacro exception->error [linter form]
  `(try ~form
        (catch Throwable e#
          (clojure.data.json/write-str
           (list (merge
                  {:line 1, :column 1
                   :msg (str ~linter ":" (.getMessage e#))
                   :level :error} (ex-data e#)))))))

(defn check-ew [ns & [opts]]
  (if-not (do-lint? :eastwood ns) "[]"
          (exception->error "Eastwood"
           (binding [*default-data-reader-fn* permissive-reader]
                              (let [ls (:warnings (eastwood.lint/lint (eastwood-options ns)))
                                    ws (map #(assoc (select-keys % [:line :column :msg])
                                                    :file (str (:uri %))
                                                    :level :warning) ls)]
                                (clojure.data.json/write-str ws))))))

(def ns->type-map (atom {}))
(defn set-file-mapping! [ns tmap]
  (swap! ns->type-map assoc ns
         (into {} (for [[{:keys [line column]} t] tmap]
                    [[line column] t]))))


(defn check-tc [ns]
  (if-not (do-lint? :typed ns) "[]"
          (exception->error "core.typed"
           (binding [*default-data-reader-fn* permissive-reader]
             (let [cni  (clojure.core.typed/check-ns-info ns :file-mapping (:typed-file-mapping (env ns)))
                   errs (map (fn [e] (assoc (:env (ex-data e))
                                           :level :error
                                           :msg (.getMessage e)))
                             (:delayed-errors cni))
                   tmap (:file-mapping cni)]
               (set-file-mapping! ns tmap)
               (clojure.data.json/write-str errs))))))

(defn build-type-map [ns]
(let [cni  (clojure.core.typed/check-ns-info ns :file-mapping true)
      tmap (:file-mapping cni)]
  (set-file-mapping! ns tmap)
  (count tmap)))

(defn check-kb [ns fname]
  (if-not (do-lint? :kibit ns) "[]"
          (exception->error "Kibit"
           (binding [*default-data-reader-fn* permissive-reader]
             (let  [_squiggly (atom [])]
               (kibit.check/check-file
                fname
                :reporter (fn [e] (swap! _squiggly conj
                                        (hash-map
                                         :msg (str "Kibit suggests using\n" (print-str (:alt e)) "\ninstead of \n" (print-str (:expr e)))
                                         :file (:file e)
                                         :line (:line e)
                                         :level :warning))))
               (clojure.data.json/write-str @_squiggly))))))

==> squiggly-clojure-0.1.9-20180723.201217-2.jar: squiggly_clojure/core.clj <==
(ns squiggly-clojure.core
  (:require eastwood.lint
            kibit.check
            clojure.data.json
            clojure.core.typed
            environ.core
            clojure.edn))

(defn- convert-env-config [config]
  (if (string? config)
    (clojure.edn/read-string config)
    config))

(defn env [ns]
  (or (:squiggly (meta (the-ns ns)))
      (convert-env-config
       (:squiggly environ.core/env))))

(defn do-lint? [checker ns]
  (and (find-ns ns)
       (if-let [checkers (:checkers (env ns))]
         (some #{checker} checkers) true)))

(defn eastwood-exclude-linters [ns]
  (if-let [excl (:eastwood-exclude-linters (env ns))]
    excl []))

(defn eastwood-options [ns]
  (merge {:source-paths ["src"]
          :namespaces [ns]
          :continue-on-exception true
          :exclude-linters (eastwood-exclude-linters ns)}
         (:eastwood-options (env ns))))

(defn permissive-reader [tag value] value)

(defmacro exception->error [linter form]
  `(try ~form
        (catch Throwable e#
          (clojure.data.json/write-str
           (list (merge
                  {:line 1, :column 1
                   :msg (str ~linter ":" (.getMessage e#))
                   :level :error} (ex-data e#)))))))

(defn check-ew [ns & [opts]]
  (if-not (do-lint? :eastwood ns) "[]"
          (exception->error "Eastwood"
           (binding [*default-data-reader-fn* permissive-reader]
                              (let [ls (:warnings (eastwood.lint/lint (eastwood-options ns)))
                                    ws (map #(assoc (select-keys % [:line :column :msg])
                                                    :file (str (:uri %))
                                                    :level :warning) ls)]
                                (clojure.data.json/write-str ws))))))

(def ns->type-map (atom {}))
(defn set-file-mapping! [ns tmap]
  (swap! ns->type-map assoc ns
         (into {} (for [[{:keys [line column]} t] tmap]
                    [[line column] t]))))


(defn check-tc [ns]
  (if-not (do-lint? :typed ns) "[]"
          (exception->error "core.typed"
           (binding [*default-data-reader-fn* permissive-reader]
             (let [cni  (clojure.core.typed/check-ns-info ns :file-mapping (:typed-file-mapping (env ns)))
                   errs (map (fn [e] (assoc (:env (ex-data e))
                                           :level :error
                                           :msg (.getMessage e)))
                             (:delayed-errors cni))
                   tmap (:file-mapping cni)]
               (set-file-mapping! ns tmap)
               (clojure.data.json/write-str errs))))))

(defn build-type-map [ns]
(let [cni  (clojure.core.typed/check-ns-info ns :file-mapping true)
      tmap (:file-mapping cni)]
  (set-file-mapping! ns tmap)
  (count tmap)))

(defn check-kb [ns fname]
  (if-not (do-lint? :kibit ns) "[]"
          (exception->error "Kibit"
           (binding [*default-data-reader-fn* permissive-reader]
             (let  [_squiggly (atom [])]
               (kibit.check/check-file
                fname
                :reporter (fn [e] (swap! _squiggly conj
                                        (hash-map
                                         :msg (str "Kibit suggests using\n" (print-str (:alt e)) "\ninstead of \n" (print-str (:expr e)))
                                         :file (:file e)
                                         :line (:line e)
                                         :level :warning))))
               (clojure.data.json/write-str @_squiggly))))))
